diff --git a/core/lib/Drupal/Core/Entity/Controller/EntityListController.php b/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
index 7a07a38..6fcec1e 100644
--- a/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
+++ b/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
@@ -7,13 +7,14 @@
 
 namespace Drupal\Core\Entity\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Defines a generic controller to list entities.
  */
-class EntityListController extends ControllerBase {
+class EntityListController {
+  use ControllerBaseTrait
 
   /**
    * Provides the listing page for any entity type.
diff --git a/core/modules/aggregator/lib/Drupal/aggregator/Controller/AggregatorController.php b/core/modules/aggregator/lib/Drupal/aggregator/Controller/AggregatorController.php
index f7313cc..f364371 100644
--- a/core/modules/aggregator/lib/Drupal/aggregator/Controller/AggregatorController.php
+++ b/core/modules/aggregator/lib/Drupal/aggregator/Controller/AggregatorController.php
@@ -8,10 +8,11 @@
 namespace Drupal\aggregator\Controller;
 
 use Drupal\Component\Utility\Xss;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\aggregator\FeedInterface;
 use Drupal\aggregator\ItemInterface;
 use Drupal\Core\Database\Connection;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
@@ -20,7 +21,8 @@
 /**
  * Returns responses for aggregator module routes.
  */
-class AggregatorController extends ControllerBase {
+class AggregatorController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The database connection.
diff --git a/core/modules/aggregator/tests/modules/aggregator_test/lib/Drupal/aggregator_test/Controller/AggregatorTestRssController.php b/core/modules/aggregator/tests/modules/aggregator_test/lib/Drupal/aggregator_test/Controller/AggregatorTestRssController.php
index 28d024b..43c95eb 100644
--- a/core/modules/aggregator/tests/modules/aggregator_test/lib/Drupal/aggregator_test/Controller/AggregatorTestRssController.php
+++ b/core/modules/aggregator/tests/modules/aggregator_test/lib/Drupal/aggregator_test/Controller/AggregatorTestRssController.php
@@ -6,7 +6,7 @@
 
 namespace Drupal\aggregator_test\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\Component\Utility\Crypt;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\HttpFoundation\Request;
@@ -14,7 +14,8 @@
 /**
  * Controller for the aggregator_test module.
  */
-class AggregatorTestRssController extends ControllerBase {
+class AggregatorTestRssController {
+  use ControllerBaseTrait;
 
   /**
    * Generates a test feed and simulates last-modified and etags.
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/Controller/CustomBlockController.php b/core/modules/block/custom_block/lib/Drupal/custom_block/Controller/CustomBlockController.php
index 3ed3842..5671969 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/Controller/CustomBlockController.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/Controller/CustomBlockController.php
@@ -8,13 +8,15 @@
 namespace Drupal\custom_block\Controller;
 
 use Drupal\Component\Plugin\PluginManagerInterface;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\custom_block\CustomBlockTypeInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\Request;
 
-class CustomBlockController extends ControllerBase {
+class CustomBlockController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The custom block storage controller.
diff --git a/core/modules/block/lib/Drupal/block/Controller/BlockAddController.php b/core/modules/block/lib/Drupal/block/Controller/BlockAddController.php
index 716bc6e..ef3f195 100644
--- a/core/modules/block/lib/Drupal/block/Controller/BlockAddController.php
+++ b/core/modules/block/lib/Drupal/block/Controller/BlockAddController.php
@@ -7,13 +7,14 @@
 
 namespace Drupal\block\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Controller for building the block instance add form.
  */
-class BlockAddController extends ControllerBase {
+class BlockAddController {
+  use ControllerBaseTrait;
 
   /**
    * Build the block instance add form.
diff --git a/core/modules/block/lib/Drupal/block/Controller/BlockController.php b/core/modules/block/lib/Drupal/block/Controller/BlockController.php
index f2ebb41..6588153 100644
--- a/core/modules/block/lib/Drupal/block/Controller/BlockController.php
+++ b/core/modules/block/lib/Drupal/block/Controller/BlockController.php
@@ -8,13 +8,14 @@
 namespace Drupal\block\Controller;
 
 use Drupal\Component\Utility\String;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Symfony\Component\HttpFoundation\Request;
 
 /**
  * Controller routines for admin block routes.
  */
-class BlockController extends ControllerBase {
+class BlockController {
+  use ControllerBaseTrait;
 
   /**
    * Returns a block theme demo page.
diff --git a/core/modules/comment/lib/Drupal/comment/Controller/AdminController.php b/core/modules/comment/lib/Drupal/comment/Controller/AdminController.php
index fc04bd8..d792dd1 100644
--- a/core/modules/comment/lib/Drupal/comment/Controller/AdminController.php
+++ b/core/modules/comment/lib/Drupal/comment/Controller/AdminController.php
@@ -8,9 +8,10 @@
 namespace Drupal\comment\Controller;
 
 use Drupal\comment\CommentManagerInterface;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\field\FieldInfo;
 use Drupal\Component\Utility\String;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\Core\Form\FormBuilderInterface;
 use Drupal\field_ui\FieldUI;
 use Symfony\Component\HttpFoundation\Request;
@@ -19,7 +20,8 @@
 /**
  * Returns responses for comment module administrative routes.
  */
-class AdminController extends ControllerBase {
+class AdminController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The field info service.
diff --git a/core/modules/comment/lib/Drupal/comment/Controller/CommentController.php b/core/modules/comment/lib/Drupal/comment/Controller/CommentController.php
index a302724..f6c4a76 100644
--- a/core/modules/comment/lib/Drupal/comment/Controller/CommentController.php
+++ b/core/modules/comment/lib/Drupal/comment/Controller/CommentController.php
@@ -9,8 +9,9 @@
 
 use Drupal\comment\CommentInterface;
 use Drupal\comment\CommentManagerInterface;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\field\FieldInfo;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\Core\Entity\EntityInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\JsonResponse;
@@ -25,7 +26,8 @@
  *
  * @see \Drupal\comment\Entity\Comment.
  */
-class CommentController extends ControllerBase {
+class CommentController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The HTTP kernel.
diff --git a/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestController.php b/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestController.php
index 836b76a..ce1bbca 100644
--- a/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestController.php
+++ b/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestController.php
@@ -7,7 +7,7 @@
 
 namespace Drupal\config_test;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\config_test\Entity\ConfigTest;
 use Drupal\Component\Utility\String;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -16,7 +16,8 @@
 /**
  * Route controller class for the config_test module.
  */
-class ConfigTestController extends ControllerBase {
+class ConfigTestController {
+  use ControllerBaseTrait;
 
   /**
    * Presents the ConfigTest edit form.
diff --git a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationController.php b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationController.php
index 0235678..4d1a901 100644
--- a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationController.php
+++ b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationController.php
@@ -9,7 +9,8 @@
 
 use Drupal\config_translation\ConfigMapperManagerInterface;
 use Drupal\Core\Access\AccessManager;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\Core\Language\Language;
 use Drupal\Core\Language\LanguageManagerInterface;
 use Drupal\Core\ParamConverter\ParamNotConvertedException;
@@ -24,7 +25,8 @@
 /**
  * Provides page callbacks for the configuration translation interface.
  */
-class ConfigTranslationController extends ControllerBase {
+class ConfigTranslationController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The configuration mapper manager.
diff --git a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationListController.php b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationListController.php
index 5ca474d..a121c86 100644
--- a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationListController.php
+++ b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationListController.php
@@ -8,14 +8,16 @@
 namespace Drupal\config_translation\Controller;
 
 use Drupal\config_translation\ConfigMapperManagerInterface;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 
 /**
  * Defines the configuration translation list controller.
  */
-class ConfigTranslationListController extends ControllerBase {
+class ConfigTranslationListController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The definition of the config mapper.
diff --git a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationMapperList.php b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationMapperList.php
index 8b7f63f..681b645 100644
--- a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationMapperList.php
+++ b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationMapperList.php
@@ -9,7 +9,8 @@
 
 use Drupal\Component\Utility\String;
 use Drupal\config_translation\ConfigMapperInterface;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
@@ -17,7 +18,8 @@
  *
  * Groups all defined configuration mapper instances by weight.
  */
-class ConfigTranslationMapperList extends ControllerBase {
+class ConfigTranslationMapperList implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * A array of configuration mapper instances.
diff --git a/core/modules/contact/lib/Drupal/contact/Controller/ContactController.php b/core/modules/contact/lib/Drupal/contact/Controller/ContactController.php
index bd7bdd7..92b74f3 100644
--- a/core/modules/contact/lib/Drupal/contact/Controller/ContactController.php
+++ b/core/modules/contact/lib/Drupal/contact/Controller/ContactController.php
@@ -7,7 +7,8 @@
 
 namespace Drupal\contact\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\Core\Flood\FloodInterface;
 use Drupal\contact\CategoryInterface;
 use Drupal\user\UserInterface;
@@ -19,7 +20,8 @@
 /**
  * Controller routines for contact routes.
  */
-class ContactController extends ControllerBase {
+class ContactController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The flood service.
diff --git a/core/modules/dblog/lib/Drupal/dblog/Controller/DbLogController.php b/core/modules/dblog/lib/Drupal/dblog/Controller/DbLogController.php
index 9728f35..6567c02 100644
--- a/core/modules/dblog/lib/Drupal/dblog/Controller/DbLogController.php
+++ b/core/modules/dblog/lib/Drupal/dblog/Controller/DbLogController.php
@@ -10,9 +10,10 @@
 use Drupal\Component\Utility\Unicode;
 use Drupal\Component\Utility\String;
 use Drupal\Component\Utility\Xss;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\Core\Database\Connection;
 use Drupal\Core\Datetime\Date;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
 use Drupal\Core\Form\FormBuilderInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -20,7 +21,8 @@
 /**
  * Returns responses for dblog routes.
  */
-class DbLogController extends ControllerBase {
+class DbLogController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The database service.
diff --git a/core/modules/edit/lib/Drupal/edit/EditController.php b/core/modules/edit/lib/Drupal/edit/EditController.php
index 2825383..b2b4b7f 100644
--- a/core/modules/edit/lib/Drupal/edit/EditController.php
+++ b/core/modules/edit/lib/Drupal/edit/EditController.php
@@ -7,7 +7,8 @@
 
 namespace Drupal\edit;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\Request;
@@ -25,7 +26,8 @@
 /**
  * Returns responses for Edit module routes.
  */
-class EditController extends ControllerBase {
+class EditController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The TempStore factory.
diff --git a/core/modules/editor/lib/Drupal/editor/EditorController.php b/core/modules/editor/lib/Drupal/editor/EditorController.php
index 0e65571..3017626 100644
--- a/core/modules/editor/lib/Drupal/editor/EditorController.php
+++ b/core/modules/editor/lib/Drupal/editor/EditorController.php
@@ -10,7 +10,7 @@
 use Drupal\Core\Ajax\AjaxResponse;
 use Drupal\Core\Ajax\OpenModalDialogCommand;
 use Drupal\Core\Ajax\CloseModalDialogCommand;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\editor\Ajax\GetUntransformedTextCommand;
 use Drupal\editor\Form\EditorImageDialog;
@@ -24,7 +24,8 @@
 /**
  * Returns responses for Editor module routes.
  */
-class EditorController extends ControllerBase {
+class EditorController {
+  use ControllerBaseTrait;
 
   /**
    * Returns an Ajax response to render a text field without transformation filters.
diff --git a/core/modules/entity/lib/Drupal/entity/Controller/EntityDisplayModeController.php b/core/modules/entity/lib/Drupal/entity/Controller/EntityDisplayModeController.php
index f0db942..6f1d889 100644
--- a/core/modules/entity/lib/Drupal/entity/Controller/EntityDisplayModeController.php
+++ b/core/modules/entity/lib/Drupal/entity/Controller/EntityDisplayModeController.php
@@ -7,12 +7,13 @@
 
 namespace Drupal\entity\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 
 /**
  * Provides methods for entity display mode routes.
  */
-class EntityDisplayModeController extends ControllerBase {
+class EntityDisplayModeController {
+  use ControllerBaseTrait;
 
   /**
    * Provides a list of eligible entity types for adding view modes.
diff --git a/core/modules/entity_reference/lib/Drupal/entity_reference/EntityReferenceController.php b/core/modules/entity_reference/lib/Drupal/entity_reference/EntityReferenceController.php
index 2dfda5d..125d4fe 100644
--- a/core/modules/entity_reference/lib/Drupal/entity_reference/EntityReferenceController.php
+++ b/core/modules/entity_reference/lib/Drupal/entity_reference/EntityReferenceController.php
@@ -7,7 +7,8 @@
 
 namespace Drupal\entity_reference;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\Request;
@@ -16,7 +17,8 @@
 /**
  * Defines route controller for entity reference.
  */
-class EntityReferenceController extends ControllerBase {
+class EntityReferenceController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The autocomplete helper for entity references.
diff --git a/core/modules/forum/lib/Drupal/forum/Controller/ForumController.php b/core/modules/forum/lib/Drupal/forum/Controller/ForumController.php
index e982429..f01be75 100644
--- a/core/modules/forum/lib/Drupal/forum/Controller/ForumController.php
+++ b/core/modules/forum/lib/Drupal/forum/Controller/ForumController.php
@@ -7,7 +7,8 @@
 
 namespace Drupal\forum\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\forum\ForumManagerInterface;
 use Drupal\taxonomy\TermInterface;
 use Drupal\taxonomy\TermStorageControllerInterface;
@@ -17,7 +18,8 @@
 /**
  * Controller routines for forum routes.
  */
-class ForumController extends ControllerBase {
+class ForumController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * Forum manager service.
diff --git a/core/modules/help/lib/Drupal/help/Controller/HelpController.php b/core/modules/help/lib/Drupal/help/Controller/HelpController.php
index 59cf945..4ad5845 100644
--- a/core/modules/help/lib/Drupal/help/Controller/HelpController.php
+++ b/core/modules/help/lib/Drupal/help/Controller/HelpController.php
@@ -7,14 +7,15 @@
 
 namespace Drupal\help\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 use Drupal\Component\Utility\String;
 
 /**
  * Controller routines for help routes.
  */
-class HelpController extends ControllerBase {
+class HelpController {
+  use ControllerBaseTrait;
 
   /**
    * Prints a page listing a glossary of Drupal terminology.
diff --git a/core/modules/history/lib/Drupal/history/Controller/HistoryController.php b/core/modules/history/lib/Drupal/history/Controller/HistoryController.php
index b605e6e..65e8a81 100644
--- a/core/modules/history/lib/Drupal/history/Controller/HistoryController.php
+++ b/core/modules/history/lib/Drupal/history/Controller/HistoryController.php
@@ -11,13 +11,14 @@
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
 use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\node\NodeInterface;
 
 /**
  * Returns responses for History module routes.
  */
-class HistoryController extends ControllerBase {
+class HistoryController {
+  use ControllerBaseTrait;
 
   /**
    * Returns a set of nodes' last read timestamps.
diff --git a/core/modules/locale/lib/Drupal/locale/Controller/LocaleController.php b/core/modules/locale/lib/Drupal/locale/Controller/LocaleController.php
index 36e6938..6f5a59c 100644
--- a/core/modules/locale/lib/Drupal/locale/Controller/LocaleController.php
+++ b/core/modules/locale/lib/Drupal/locale/Controller/LocaleController.php
@@ -6,13 +6,14 @@
 
 namespace Drupal\locale\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Symfony\Component\HttpFoundation\RedirectResponse;
 
 /**
  * Return response for manual check translations.
  */
-class LocaleController extends ControllerBase {
+class LocaleController {
+  use ControllerBaseTrait;
 
   /**
    * Checks for translation updates and displays the translations status.
diff --git a/core/modules/menu/lib/Drupal/menu/Controller/MenuController.php b/core/modules/menu/lib/Drupal/menu/Controller/MenuController.php
index 0b77263..ce98301 100644
--- a/core/modules/menu/lib/Drupal/menu/Controller/MenuController.php
+++ b/core/modules/menu/lib/Drupal/menu/Controller/MenuController.php
@@ -8,7 +8,7 @@
 namespace Drupal\menu\Controller;
 
 use Drupal\Component\Utility\Xss;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\system\MenuInterface;
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\Request;
@@ -16,7 +16,8 @@
 /**
  * Returns responses for Menu routes.
  */
-class MenuController extends ControllerBase {
+class MenuController {
+  use ControllerBaseTrait;
 
   /**
    * Gets all the available menus and menu items as a JavaScript array.
diff --git a/core/modules/node/lib/Drupal/node/Controller/NodeController.php b/core/modules/node/lib/Drupal/node/Controller/NodeController.php
index 273f441..ce919f0 100644
--- a/core/modules/node/lib/Drupal/node/Controller/NodeController.php
+++ b/core/modules/node/lib/Drupal/node/Controller/NodeController.php
@@ -8,14 +8,15 @@
 namespace Drupal\node\Controller;
 
 use Drupal\Component\Utility\String;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\node\NodeTypeInterface;
 use Drupal\node\NodeInterface;
 
 /**
  * Returns responses for Node routes.
  */
-class NodeController extends ControllerBase {
+class NodeController {
+  use ControllerBaseTrait;
 
   /**
    * Displays add content links for available content types.
diff --git a/core/modules/search/lib/Drupal/search/Controller/SearchController.php b/core/modules/search/lib/Drupal/search/Controller/SearchController.php
index f683c5e..8c40941 100644
--- a/core/modules/search/lib/Drupal/search/Controller/SearchController.php
+++ b/core/modules/search/lib/Drupal/search/Controller/SearchController.php
@@ -7,7 +7,8 @@
 
 namespace Drupal\search\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\search\SearchPageInterface;
 use Drupal\search\SearchPageRepositoryInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -16,7 +17,8 @@
 /**
  * Route controller for search.
  */
-class SearchController extends ControllerBase {
+class SearchController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The search page repository.
diff --git a/core/modules/shortcut/lib/Drupal/shortcut/Controller/ShortcutController.php b/core/modules/shortcut/lib/Drupal/shortcut/Controller/ShortcutController.php
index 1ed6f0a..480248c 100644
--- a/core/modules/shortcut/lib/Drupal/shortcut/Controller/ShortcutController.php
+++ b/core/modules/shortcut/lib/Drupal/shortcut/Controller/ShortcutController.php
@@ -7,14 +7,15 @@
 
 namespace Drupal\shortcut\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\shortcut\ShortcutSetInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Provides route responses for taxonomy.module.
  */
-class ShortcutController extends ControllerBase {
+class ShortcutController {
+  use ControllerBaseTrait;
 
   /**
    * Returns a rendered edit form to create a new shortcut associated to the
diff --git a/core/modules/shortcut/lib/Drupal/shortcut/Controller/ShortcutSetController.php b/core/modules/shortcut/lib/Drupal/shortcut/Controller/ShortcutSetController.php
index 2d90342..d31fc5f 100644
--- a/core/modules/shortcut/lib/Drupal/shortcut/Controller/ShortcutSetController.php
+++ b/core/modules/shortcut/lib/Drupal/shortcut/Controller/ShortcutSetController.php
@@ -7,17 +7,16 @@
 
 namespace Drupal\shortcut\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\shortcut\ShortcutSetInterface;
-use Symfony\Component\DependencyInjection\ContainerInterface;
-use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
 
 /**
  * Builds the page for administering shortcut sets.
  */
-class ShortcutSetController extends ControllerBase {
+class ShortcutSetController {
+  use ControllerBaseTrait;
 
   /**
    * Creates a new link in the provided shortcut set.
diff --git a/core/modules/system/lib/Drupal/system/Controller/AdminController.php b/core/modules/system/lib/Drupal/system/Controller/AdminController.php
index f1e231f..be527de 100644
--- a/core/modules/system/lib/Drupal/system/Controller/AdminController.php
+++ b/core/modules/system/lib/Drupal/system/Controller/AdminController.php
@@ -7,12 +7,13 @@
 
 namespace Drupal\system\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 
 /**
  * Controller for admin section.
  */
-class AdminController extends ControllerBase {
+class AdminController {
+  use ControllerBaseTrait;
 
   /**
    * Prints a listing of admin tasks, organized by module.
diff --git a/core/modules/system/lib/Drupal/system/Controller/SystemController.php b/core/modules/system/lib/Drupal/system/Controller/SystemController.php
index 5f55d6e..f1dbe77 100644
--- a/core/modules/system/lib/Drupal/system/Controller/SystemController.php
+++ b/core/modules/system/lib/Drupal/system/Controller/SystemController.php
@@ -8,7 +8,8 @@
 namespace Drupal\system\Controller;
 
 use Drupal\Component\Utility\Json;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\Core\Entity\Query\QueryFactory;
 use Drupal\Core\Extension\ThemeHandlerInterface;
 use Drupal\Core\Form\FormBuilderInterface;
@@ -19,7 +20,8 @@
 /**
  * Returns responses for System routes.
  */
-class SystemController extends ControllerBase {
+class SystemController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The entity query factory object.
diff --git a/core/modules/system/lib/Drupal/system/Controller/ThemeController.php b/core/modules/system/lib/Drupal/system/Controller/ThemeController.php
index ece04d5..31e0b75 100644
--- a/core/modules/system/lib/Drupal/system/Controller/ThemeController.php
+++ b/core/modules/system/lib/Drupal/system/Controller/ThemeController.php
@@ -7,7 +7,7 @@
 
 namespace Drupal\system\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
@@ -15,7 +15,8 @@
 /**
  * Controller for theme handling.
  */
-class ThemeController extends ControllerBase {
+class ThemeController {
+  use ControllerBaseTrait;
 
   /**
    * Disables a theme.
diff --git a/core/modules/system/lib/Drupal/system/CronController.php b/core/modules/system/lib/Drupal/system/CronController.php
index 67d9354..e40fbdd 100644
--- a/core/modules/system/lib/Drupal/system/CronController.php
+++ b/core/modules/system/lib/Drupal/system/CronController.php
@@ -7,15 +7,17 @@
 
 namespace Drupal\system;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\Core\CronInterface;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\Response;
 
 /**
  * Controller for Cron handling.
  */
-class CronController extends ControllerBase {
+class CronController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The cron service.
diff --git a/core/modules/system/lib/Drupal/system/FileDownloadController.php b/core/modules/system/lib/Drupal/system/FileDownloadController.php
index a65342d..fb976ba 100644
--- a/core/modules/system/lib/Drupal/system/FileDownloadController.php
+++ b/core/modules/system/lib/Drupal/system/FileDownloadController.php
@@ -7,7 +7,7 @@
 
 namespace Drupal\system;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
 use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
@@ -16,7 +16,8 @@
 /**
  * System file controller.
  */
-class FileDownloadController extends ControllerBase {
+class FileDownloadController {
+  use ControllerBaseTrait;
 
   /**
    * Handles private file transfers.
diff --git a/core/modules/system/tests/modules/error_test/lib/Drupal/error_test/Controller/ErrorTestController.php b/core/modules/system/tests/modules/error_test/lib/Drupal/error_test/Controller/ErrorTestController.php
index 7a4bf90..2be2d53 100644
--- a/core/modules/system/tests/modules/error_test/lib/Drupal/error_test/Controller/ErrorTestController.php
+++ b/core/modules/system/tests/modules/error_test/lib/Drupal/error_test/Controller/ErrorTestController.php
@@ -6,14 +6,16 @@
 
 namespace Drupal\error_test\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\Core\Database\Connection;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Controller routines for error_test routes.
  */
-class ErrorTestController extends ControllerBase {
+class ErrorTestController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The database connection.
diff --git a/core/modules/system/tests/modules/form_test/lib/Drupal/form_test/Controller/FormTestController.php b/core/modules/system/tests/modules/form_test/lib/Drupal/form_test/Controller/FormTestController.php
index b7ed78c..a09f583 100644
--- a/core/modules/system/tests/modules/form_test/lib/Drupal/form_test/Controller/FormTestController.php
+++ b/core/modules/system/tests/modules/form_test/lib/Drupal/form_test/Controller/FormTestController.php
@@ -6,13 +6,14 @@
 
 namespace Drupal\form_test\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\Core\Language\Language;
 
 /**
  * Controller routines for form_test routes.
  */
-class FormTestController extends ControllerBase {
+class FormTestController {
+  use ControllerBaseTrait;
 
   /**
    * Returns two instances of the node form.
diff --git a/core/modules/system/tests/modules/router_test_directory/lib/Drupal/router_test/TestContent.php b/core/modules/system/tests/modules/router_test_directory/lib/Drupal/router_test/TestContent.php
index 57a1a85..adc0e65 100644
--- a/core/modules/system/tests/modules/router_test_directory/lib/Drupal/router_test/TestContent.php
+++ b/core/modules/system/tests/modules/router_test_directory/lib/Drupal/router_test/TestContent.php
@@ -7,7 +7,8 @@
 
 namespace Drupal\router_test;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\user\UserInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\Request;
@@ -16,7 +17,8 @@
 /**
  * Test controllers that are intended to be wrapped in a main controller.
  */
-class TestContent extends ControllerBase {
+class TestContent implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * The HTTP kernel.
diff --git a/core/modules/system/tests/modules/session_test/lib/Drupal/session_test/Controller/SessionTestController.php b/core/modules/system/tests/modules/session_test/lib/Drupal/session_test/Controller/SessionTestController.php
index 6b00515..dc1ec31 100644
--- a/core/modules/system/tests/modules/session_test/lib/Drupal/session_test/Controller/SessionTestController.php
+++ b/core/modules/system/tests/modules/session_test/lib/Drupal/session_test/Controller/SessionTestController.php
@@ -7,7 +7,7 @@
 
 namespace Drupal\session_test\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
@@ -15,7 +15,8 @@
 /**
  * Controller providing page callbacks for the action admin interface.
  */
-class SessionTestController extends ControllerBase {
+class SessionTestController {
+  use ControllerBaseTrait;
   /**
    * Prints the stored session value to the screen.
    *
diff --git a/core/modules/system/tests/modules/system_test/lib/Drupal/system_test/Controller/SystemTestController.php b/core/modules/system/tests/modules/system_test/lib/Drupal/system_test/Controller/SystemTestController.php
index 868117a..8f8d86b 100644
--- a/core/modules/system/tests/modules/system_test/lib/Drupal/system_test/Controller/SystemTestController.php
+++ b/core/modules/system/tests/modules/system_test/lib/Drupal/system_test/Controller/SystemTestController.php
@@ -7,12 +7,13 @@
 
 namespace Drupal\system_test\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 
 /**
  * Controller routines for system_test routes.
  */
-class SystemTestController extends ControllerBase {
+class SystemTestController {
+  use ControllerBaseTrait;
 
   /**
    * Tests main content fallback.
diff --git a/core/modules/system/tests/modules/theme_test/lib/Drupal/theme_test/ThemeTestController.php b/core/modules/system/tests/modules/theme_test/lib/Drupal/theme_test/ThemeTestController.php
index 3684793..8c1d377 100644
--- a/core/modules/system/tests/modules/theme_test/lib/Drupal/theme_test/ThemeTestController.php
+++ b/core/modules/system/tests/modules/theme_test/lib/Drupal/theme_test/ThemeTestController.php
@@ -7,12 +7,13 @@
 
 namespace Drupal\theme_test;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 
 /**
  * Controller routines for theme test routes.
  */
-class ThemeTestController extends ControllerBase {
+class ThemeTestController {
+  use ControllerBaseTrait;
 
   /**
    * A theme template that overrides a theme function.
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Controller/TaxonomyController.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Controller/TaxonomyController.php
index 9ade6c9..6f3a660 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Controller/TaxonomyController.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Controller/TaxonomyController.php
@@ -8,7 +8,7 @@
 namespace Drupal\taxonomy\Controller;
 
 use Drupal\Component\Utility\Xss;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\taxonomy\TermInterface;
 use Drupal\taxonomy\VocabularyInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -16,7 +16,8 @@
 /**
  * Provides route responses for taxonomy.module.
  */
-class TaxonomyController extends ControllerBase {
+class TaxonomyController {
+  use ControllerBaseTrait;
 
   /**
    * Returns a rendered edit form to create a new term associated to the given vocabulary.
diff --git a/core/modules/toolbar/lib/Drupal/toolbar/Controller/ToolbarController.php b/core/modules/toolbar/lib/Drupal/toolbar/Controller/ToolbarController.php
index d5fc878..41c2119 100644
--- a/core/modules/toolbar/lib/Drupal/toolbar/Controller/ToolbarController.php
+++ b/core/modules/toolbar/lib/Drupal/toolbar/Controller/ToolbarController.php
@@ -8,14 +8,15 @@
 namespace Drupal\toolbar\Controller;
 
 use Drupal\Core\Access\AccessInterface;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\Request;
 
 /**
  * Defines a controller for the toolbar module.
  */
-class ToolbarController extends ControllerBase {
+class ToolbarController {
+  use ControllerBaseTrait;
 
   /**
    * Returns the rendered subtree of each top-level toolbar link.
diff --git a/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerPage.php b/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerPage.php
index a9d667a..510c3f4 100644
--- a/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerPage.php
+++ b/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerPage.php
@@ -7,12 +7,13 @@
 
 namespace Drupal\tracker\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 
 /**
  * Controller for tracker.page route.
  */
-class TrackerPage extends ControllerBase {
+class TrackerPage {
+  use ControllerBaseTrait;
 
   /**
    * Content callback for the tracker.page route.
diff --git a/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerUserRecent.php b/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerUserRecent.php
index 4b644ae..8df86e3 100644
--- a/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerUserRecent.php
+++ b/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerUserRecent.php
@@ -7,13 +7,14 @@
 
 namespace Drupal\tracker\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\user\UserInterface;
 
 /**
  * Controller for tracker.users_recent_content route.
  */
-class TrackerUserRecent extends ControllerBase {
+class TrackerUserRecent {
+  use ControllerBaseTrait;
 
   /**
    * Content callback for the tracker.users_recent_content route.
diff --git a/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerUserTab.php b/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerUserTab.php
index 49a7574..f41a45c 100644
--- a/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerUserTab.php
+++ b/core/modules/tracker/lib/Drupal/tracker/Controller/TrackerUserTab.php
@@ -7,14 +7,15 @@
 
 namespace Drupal\tracker\Controller;
 
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\user\UserInterface;
 use Drupal\Component\Utility\String;
 
 /**
  * Controller for tracker.user_tab route.
  */
-class TrackerUserTab extends ControllerBase {
+class TrackerUserTab {
+  use ControllerBaseTrait;
 
   /**
    * Content callback for the tracker.user_tab route.
diff --git a/core/modules/update/lib/Drupal/update/Controller/UpdateController.php b/core/modules/update/lib/Drupal/update/Controller/UpdateController.php
index f9419b3..488ef15 100644
--- a/core/modules/update/lib/Drupal/update/Controller/UpdateController.php
+++ b/core/modules/update/lib/Drupal/update/Controller/UpdateController.php
@@ -7,14 +7,16 @@
 
 namespace Drupal\update\Controller;
 
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\update\UpdateManagerInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 
 /**
  * Controller routines for update routes.
  */
-class UpdateController extends ControllerBase {
+class UpdateController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * Update manager service.
diff --git a/core/modules/user/lib/Drupal/user/Controller/UserController.php b/core/modules/user/lib/Drupal/user/Controller/UserController.php
index 6710afb..f472f60 100644
--- a/core/modules/user/lib/Drupal/user/Controller/UserController.php
+++ b/core/modules/user/lib/Drupal/user/Controller/UserController.php
@@ -8,14 +8,15 @@
 namespace Drupal\user\Controller;
 
 use Drupal\Component\Utility\Xss;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
 use Drupal\user\UserInterface;
 use Symfony\Component\HttpFoundation\Request;
 
 /**
  * Controller routines for user routes.
  */
-class UserController extends ControllerBase {
+class UserController {
+  use ControllerBaseTrait;
 
   /**
    * Returns the user page.
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php b/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
index c68759a..5a35dd8 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
@@ -8,7 +8,8 @@
 namespace Drupal\views_ui\Controller;
 
 use Drupal\Component\Utility\String;
-use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Controller\ControllerBaseTrait;
+use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\views\ViewExecutable;
 use Drupal\views\ViewStorageInterface;
 use Drupal\views_ui\ViewUI;
@@ -22,7 +23,8 @@
 /**
  * Returns responses for Views UI routes.
  */
-class ViewsUIController extends ControllerBase {
+class ViewsUIController implements ContainerInjectionInterface {
+  use ControllerBaseTrait;
 
   /**
    * Stores the Views data cache object.
diff --git a/core/tests/Drupal/Tests/Core/Controller/ControllerBaseTest.php b/core/tests/Drupal/Tests/Core/Controller/ControllerBaseTest.php
index 0345f0e..a14f8e0 100644
--- a/core/tests/Drupal/Tests/Core/Controller/ControllerBaseTest.php
+++ b/core/tests/Drupal/Tests/Core/Controller/ControllerBaseTest.php
@@ -17,7 +17,7 @@ class ControllerBaseTest extends UnitTestCase {
   /**
    * The tested controller base class.
    *
-   * @var \Drupal\Core\Controller\ControllerBase|\PHPUnit_Framework_MockObject_MockObject
+   * @var \Drupal\Core\Controller\ControllerBaseTrait|\PHPUnit_Framework_MockObject_MockObject
    */
   protected $controllerBase;
 

diff --git a/core/lib/Drupal/Core/Controller/ControllerBase.php b/core/lib/Drupal/Core/Controller/ControllerBaseTrait.php
similarity index 95%
rename from core/lib/Drupal/Core/Controller/ControllerBase.php
rename to core/lib/Drupal/Core/Controller/ControllerBaseTrait.php
index 7eb368a..301b29a 100644
--- a/core/lib/Drupal/Core/Controller/ControllerBase.php
+++ b/core/lib/Drupal/Core/Controller/ControllerBaseTrait.php
@@ -7,14 +7,12 @@
 
 namespace Drupal\Core\Controller;
 
-use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
-use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\RedirectResponse;
 
 /**
- * Utility base class for thin controllers.
+ * Utility trait for thin controller classes.
  *
  * Controllers that use this base class have access to a number of utility
  * methods and to the Container, which can greatly reduce boilerplate dependency
  * handling code.  However, it also makes the class considerably more
  * difficult to unit test. Therefore this base class should only be used by
@@ -30,7 +28,7 @@
  *
  * @see \Drupal\Core\DependencyInjection\ContainerInjectionInterface
  */
-abstract class ControllerBase implements ContainerInjectionInterface {
+trait ControllerBaseTrait {
 
   /**
    * The entity manager.
@@ -110,13 +108,6 @@
   protected $formBuilder;
 
   /**
-   * {@inheritdoc}
-   */
-  public static function create(ContainerInterface $container) {
-    return new static();
-  }
-
-  /**
    * Retrieves the entity manager service.
    *
    * @return \Drupal\Core\Entity\EntityManagerInterface
@@ -7,14 +7,12 @@
  *
- * Controllers that use this base class have access to a number of utility
+ * Controllers that use this trait have access to a number of utility
  * methods and to the Container, which can greatly reduce boilerplate dependency
  * handling code.  However, it also makes the class considerably more